/*
 * This file is a part of Netacka 3D.
 *
 * Copyright 2010
 * Leszek Bartkowski, Mikołaj Dądela, Paweł Marczewski, Jan Szejko
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */


package netacka3d.misc.android;

import java.io.IOException;

import netacka3d.data.MatchSettings;
import netacka3d.data.Player;
import netacka3d.data.PlayerColor;
import netacka3d.data.PlayersTable;
import netacka3d.data.serialization.Serialization;
import netacka3d.logic.Game;
import netacka3d.misc.FileIO;
import netacka3d.misc.Logger;
import netacka3d.misc.Logger.Severity;
import android.content.Context;

public class Init {
    public static void init(Context context) {
        FileIO.setBackend(new AndroidFileIOBackend(context));
        Logger.setBackend(new AndroidLoggerBackend());
        Logger.setVerbosity(Severity.CRITICAL);
        Thread.setDefaultUncaughtExceptionHandler(new Logger.ExceptionHandler());

        new Thread() {
            public void run() {
                initJson();
            }
        }.start();
    }

    /* Hack - wymusza inicjację biblioteki JSONowej, żeby potem nie było
     * przestojów. */
    private static void initJson() {
        initJson(new MatchSettings(), MatchSettings.class);
        initJson(Game.MatchState.ROUND, Game.MatchState.class);
        initJson("bla", String.class);
        PlayersTable tbl = new PlayersTable();
        tbl.addPlayer(new Player(1, "a", PlayerColor.RED));
        initJson(tbl, PlayersTable.class);
    }

    private static <T> void initJson(T obj, Class<T> type) {
        String s;
        try {
            s = Serialization.mapper.writeValueAsString(obj);
            Serialization.mapper.readValue(s, type);
        } catch (IOException e) {
            // TODO Auto-generated catch block
            e.printStackTrace();
        }
    }
}
