/*
 * This file is a part of Netacka 3D.
 *
 * Copyright 2010
 * Leszek Bartkowski, Mikołaj Dądela, Paweł Marczewski, Jan Szejko
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */


package netacka3d.ui.android;

import netacka3d.data.*;
import netacka3d.logic.*;
import netacka3d.misc.Logger;
import netacka3d.misc.android.AccelerometerListener;
import netacka3d.misc.android.AccelerometerManager;
import netacka3d.misc.android.Init;
import android.app.Activity;
import android.content.pm.ActivityInfo;
import android.content.res.Configuration;
import android.os.Bundle;
import android.os.Debug;
import android.view.View;
import android.view.View.OnClickListener;
import android.widget.Button;
import android.widget.EditText;
import android.content.Context;
import android.app.AlertDialog;
import android.app.AlertDialog.Builder;

/**
 * Główna klasa aplikacji. Pokazuje menu i czeka na klik.
 */
public class Netacka3D extends Activity implements AccelerometerListener {
    
    private static Context CONTEXT;
    private GameView gameView = null; 
    
    @Override
    public void onCreate(Bundle savedInstanceState) {
        // wtf? jak to robię to na poziomym telefonie jest ok
        //setRequestedOrientation(ActivityInfo.SCREEN_ORIENTATION_PORTRAIT);
        super.onCreate(savedInstanceState);
        //Debug.startMethodTracing("netacka3d");
        
        setRequestedOrientation(ActivityInfo.SCREEN_ORIENTATION_LANDSCAPE);
        Init.init(getApplicationContext());
        Logger.i("starting!");
        initializeMenu();
        CONTEXT = this;
    }
    
    protected void onResume() {
        super.onResume();
        if (AccelerometerManager.isSupported()) {
            AccelerometerManager.startListening(this);
        }
    }
    
    protected void onStop() {
        super.onStop();
        if (gameView != null)
            gameView.end();
        Debug.stopMethodTracing();
        if (AccelerometerManager.isListening()) {
            AccelerometerManager.stopListening();
        }
    }

    // żeby obracanie nic nie robiło
    public void onConfigurationChanged(Configuration newConfig) {
        super.onConfigurationChanged(newConfig);
    }

    public void initializeMenu() {
        setContentView(R.layout.main_menu);
        ((Button) findViewById(R.id.join_game_button))
                .setOnClickListener(joinGameButtonListener);
        ((Button) findViewById(R.id.help_button))
        .setOnClickListener(helpButtonListener);
        ((Button) findViewById(R.id.exit_button))
        .setOnClickListener(exitButtonListener);
        
    }

    OnClickListener joinGameButtonListener = new OnClickListener() {
        public void onClick(View v) {
            setContentView(R.layout.join_game);
            ((Button) findViewById(R.id.back))
            .setOnClickListener(backToMenuListener);
            ((Button) findViewById(R.id.join))
            .setOnClickListener(newGameListener);
        }
    };
    OnClickListener helpButtonListener = new OnClickListener() {
        public void onClick(View v) {
            setContentView(R.layout.help);
            ((Button) findViewById(R.id.back))
            .setOnClickListener(backToMenuListener);
        }
    };
    OnClickListener exitButtonListener = new OnClickListener() {
        public void onClick(View v) {
            Netacka3D.this.finish();
        }
    };
    OnClickListener backToMenuListener = new OnClickListener() {
        public void onClick(View v) {
            initializeMenu();
        }
    };
    
    OnClickListener newGameListener = new OnClickListener() {
        public void onClick(View v) {
            EditText addrField, nickField, portField;
            String nick, addr;
            ClientController controller = new ClientController();
            int port;
            addrField = (EditText) findViewById(R.id.address);
            portField = (EditText) findViewById(R.id.port);
            nickField = (EditText) findViewById(R.id.nickname);
            
            try {
                nick = nickField.getText().toString();
                addr = addrField.getText().toString();
                port = Integer.parseInt(portField.getText().toString());
                gameView = new GameView(Netacka3D.this, controller);
                setContentView(gameView);
                controller.registerGameListener(new MyGameListener());
                controller.connect(nick, PlayerColor.RED, addr, port);                
            } catch (NumberFormatException e) {
                /* podano zły port - nic nie robimy */
            }                       
        }
    };
    
    private class MyGameListener implements GameListener {

        public void onSegment(int playerId, int t, Segment segment) {
        }

        public void onStart(int playerId) {
        }

        public void onStep(boolean stateChanged, Game game) {
        }

        public void onStop(final String reason) {
            runOnUiThread(new Runnable() {
                public void run() {
                    initializeMenu();
                    Builder builder = new AlertDialog.Builder(Netacka3D.this);
                    builder.setTitle("Game Stop");
                    builder.setMessage(reason);
                    builder.setNeutralButton("OK", null);
                    builder.show();
                }
            });
            if (gameView != null) {
                gameView.end();
                gameView = null;
            }
        }
        
    }
    
    public static Context getContext() {
        return CONTEXT;
    }

    @Override
    public void onAccelerationChanged(float x, float y, float z) {
        //Logger.i("akcel: "+x+" "+y+" "+z);
        if (gameView != null) {
            gameView.processAccelerometer(x, y, z);
        }
    }

    @Override
    public void onShake(float force) {
        // nic?
    }
    
}