/*
 * This file is a part of Netacka 3D.
 *
 * Copyright 2010
 * Leszek Bartkowski, Mikołaj Dądela, Paweł Marczewski, Jan Szejko
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */


package netacka3d.data.serialization;

import java.nio.charset.Charset;

import org.codehaus.jackson.map.DeserializationConfig;
import org.codehaus.jackson.map.ObjectMapper;
import org.codehaus.jackson.map.SerializationConfig;
import org.codehaus.jackson.map.annotate.JsonSerialize.Inclusion;

/** 
 * Opcje serializacji i takie tam.
 * 
 * Użycie:
 * Serialization.mapper.readValue(...)
 * Serialization.mapper.writeValue(...)
 */
public class Serialization {    
    public static ObjectMapper mapper;
    
    public static final Charset charset = Charset.forName("UTF-8");
    
    static {
        mapper = new ObjectMapper();        
        
        SerializationConfig scfg = mapper.copySerializationConfig();
        scfg.setSerializationInclusion(Inclusion.NON_NULL);
        scfg.disable(SerializationConfig.Feature.FAIL_ON_EMPTY_BEANS);
        scfg.disable(SerializationConfig.Feature.INDENT_OUTPUT);
        scfg.disable(SerializationConfig.Feature.AUTO_DETECT_GETTERS);
        scfg.disable(SerializationConfig.Feature.AUTO_DETECT_IS_GETTERS);
        scfg.enable(SerializationConfig.Feature.USE_STATIC_TYPING);
        mapper.setSerializationConfig(scfg);
        
        DeserializationConfig dcfg = mapper.copyDeserializationConfig();
        dcfg.disable(DeserializationConfig.Feature.AUTO_DETECT_SETTERS);
        dcfg.disable(DeserializationConfig.Feature.USE_GETTERS_AS_SETTERS);
        dcfg.disable(DeserializationConfig.Feature.AUTO_DETECT_CREATORS);
        mapper.setDeserializationConfig(dcfg);
    }
}
