/*
 * This file is a part of Netacka 3D.
 *
 * Copyright 2010
 * Leszek Bartkowski, Mikołaj Dądela, Paweł Marczewski, Jan Szejko
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */


package netacka3d.logic.bots;

import netacka3d.data.Direction;
import netacka3d.data.Segment;
import netacka3d.logic.ClientController;
import netacka3d.logic.Game;
import netacka3d.logic.GameListener;

public abstract class Bot extends ClientController {
    
    public Bot() {
        registerGameListener(new Listener());
    }

    abstract protected Direction doStep(boolean stateChanged);
    
    @Override
    public void setPlayerDirection(Direction dir) {
        throw new UnsupportedOperationException();
    }

    private class Listener implements GameListener {

        @Override
        public void onSegment(int playerId, int t, Segment segment) {}

        @Override
        public void onStart(int playerId) {}

        @Override
        public void onStep(boolean stateChanged, Game game) {
            Bot.super.setPlayerDirection(doStep(stateChanged));
        }

        @Override
        public void onStop(String reason) {}
        
    }

    private static String[] botList = new String[] {
        "RandomBot",
        "SpinBot",
        "Sigma"
    };
    
    public static String[] getBotList() {
        return botList;
    }
    
    public static Bot makeBot(String name) 
        throws ClassNotFoundException, 
            InstantiationException, 
            IllegalAccessException 
    {
        name = "netacka3d.logic.bots." + name;
        Class<?> cls = ClassLoader.getSystemClassLoader().loadClass(name);
        return (Bot)cls.newInstance();
    }
}
