/*
 * This file is a part of Netacka 3D.
 *
 * Copyright 2010
 * Leszek Bartkowski, Mikołaj Dądela, Paweł Marczewski, Jan Szejko
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */


package netacka3d.misc;

import java.io.InputStream;
import java.io.FileNotFoundException;
import java.io.IOException;
import java.nio.ByteBuffer;

public class FileIO {

    static FileIOBackend handler = new FileIOBackend();

    public static InputStream openFile(String filename) 
                throws FileNotFoundException {
        long time = System.currentTimeMillis();
        InputStream stream = handler.openFile(filename);
        Logger.d("otwieranie pliku "+filename+" trwalo "+(System.currentTimeMillis()-time)+"ms");
        return stream;
    }
   
    /**
     * Załaduj obrazek.
     * @param filename nazwa pliku
     * @param dims null, albo miejsce na tablicę int[2] na wymiary
     * @return ByteBuffer dla OpenGL z danymi w formacie RGBA
     * @throws IOException
     */
    public static ByteBuffer loadImage(String filename,
            int[] dims) 
                throws IOException {
        long time = System.currentTimeMillis();
        ByteBuffer image = handler.loadImage(filename, dims);
        Logger.d("otwieranie obrazka "+filename+" trwalo "+(System.currentTimeMillis()-time)+"ms");
        return image;
    }
    
    public static void setBackend(FileIOBackend h) {
        handler = h;
    }

}
