/*
 * This file is a part of Netacka 3D.
 *
 * Copyright 2010
 * Leszek Bartkowski, Mikołaj Dądela, Paweł Marczewski, Jan Szejko
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */


package netacka3d.network;

import java.io.IOException;
import java.nio.ByteBuffer;

import netacka3d.data.PlayerColor;
import netacka3d.data.MatchSettings;
import netacka3d.data.PlayersTable;
import netacka3d.data.serialization.Serialization;
import netacka3d.logic.Game.MatchState;
import netacka3d.misc.Logger;

/**
 * Klasa pomocnicza reprezentująca komunikat TCP.
 * W chwili obecnej klasa-muzeum, nigdzie nie używana
 * @author Leszek
 */
class TCPMessage {
    public enum Type {GET_GAME_INFO, GAME_INFO, JOIN, NOT_JOINED, JOINED,
        NEW_GAME_STATE, BYE }
    public Type type;
    
    public int num = 0;

    public MatchState state;
    public MatchSettings settings;
    public PlayersTable players;
    public Integer stepNum;
    public int activePlayersCount;
    
    public String text;
    public PlayerColor color;
    public Integer id;
    

    public TCPMessage() {
        num = n++;
    }
    /**
     * serializuje wiadomość do bufora
     * @return bufor z wiadomością
     */
    public byte[] asBytes() {
        try {            
            return Serialization.mapper.writeValueAsBytes(this);
        } catch (IOException e) {
            Logger.logException(e);
            throw new RuntimeException(e);
        }
    }
    
    /**
     * Deserializuje TCPMessage.
     * 
     * @return wiadomość, lub null jeśli się nie udało
     */
    public static TCPMessage fromByteBuffer(ByteBuffer buf, int pos) {
        try {            
            return Serialization.mapper.readValue(buf.array(), 
                   pos, buf.limit()-pos, TCPMessage.class);
        } catch (IOException e) {
            Logger.logException(e);
            return null;
        }
    }
    
    static int n = 1;
}