/*
 * This file is a part of Netacka 3D.
 *
 * Copyright 2010
 * Leszek Bartkowski, Mikołaj Dądela, Paweł Marczewski, Jan Szejko
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */


package netacka3d.network;

import java.io.IOException;

import netacka3d.Init;
import netacka3d.data.MatchSettings;
import netacka3d.logic.ServerController;
import netacka3d.misc.Logger;

import org.junit.Before;
import org.junit.Test;
import static org.junit.Assert.*;

public class ServerFinderTest {
    
    @Before
    public void init() {
        Init.init();
    }
    
    @Test
    public void simpleTest() throws IOException, InterruptedException {
        ServerController con = new ServerController();
        MatchSettings mS = new MatchSettings() {{ arenaName = "cube"; }};
        con.startGame("bla", mS, UDPProtocol.DEFAULT_PORT);
        Thread.sleep(300);
        
        TestListener listener = new TestListener();
        
        ServerFinder fi = new ServerFinder(listener);
        fi.start();
        for (int i = 0; i < 100; ++i) {
            Thread.sleep(100);
            if (listener.done)
                break;
        }
        assertTrue(listener.done);
        fi.stop();
        con.endGame();
    } 
    
    private static class TestListener implements ServerFinderListener {
        public boolean done = false;
        public void onServer(String addr, int portTCP, int portUDP,
                MatchSettings matchSettings, int activePlayersCount) {
            Logger.i("found " + addr);
            done = true;
        }
    }
}
