# -*- coding: utf-8 -*-

# This file is a part of Netacka 3D.
#
# Copyright 2010
# Leszek Bartkowski, Mikołaj Dądela, Paweł Marczewski, Jan Szejko
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.


import sys
from os import listdir, makedirs, remove
from os.path import join, isdir, isfile

from preprocessor import preprocess_file

def main():
    if len(sys.argv) != 3:
        print("Usage: python preprocessor.py in-path out-path")
        print("This scpript copies all files from in-path, and places their preprocessed versions in out-path.")
        sys.exit()
    dir_in = sys.argv[1]
    dir_out = sys.argv[2]
    if not isdir(dir_out):
        makedirs(dir_out)
    for f in listdir(dir_out):
        outf = join(dir_out, f)
        if isfile(outf) and "//#autogenerated" not in open(outf).read():
            raise Exception
        remove(outf)
    for f in listdir(dir_in):
        #print f
        #if isdir(join(dir_in, f)): recurse!
        inf = join(dir_in, f)
        outf = join(dir_out, f)
        if inf.endswith('.java'):
            print("{0} -> {1}".format(inf, outf))
            preprocess_file(inf, outf)


if __name__ == "__main__":
    main()


# set PATH=%PATH%;C:\Program Files\Python26
