/*
 * This file is a part of Netacka 3D.
 *
 * Copyright 2010
 * Leszek Bartkowski, Mikołaj Dądela, Paweł Marczewski, Jan Szejko
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */


package netacka3d.graphics.pc; //#.pc
//#.android package netacka3d.graphics.android;

import java.nio.ByteBuffer;
//import java.nio.ByteOrder;
import java.nio.FloatBuffer;
//import javax.vecmath.*;

//import java.awt.Container;              //#.pc
import javax.media.opengl.*;            //#.pc

//import javax.media.opengl.glu.GLU;      //#.pc

//import com.sun.opengl.util.Animator;    //#.pc
//import com.sun.opengl.util.FPSAnimator; //#.pc

//#.android import javax.microedition.khronos.egl.EGLConfig;
//#.android import javax.microedition.khronos.opengles.GL10;

//#.android import android.opengl.GLU;
//#.android import android.opengl.GLSurfaceView.Renderer;
//#.android import android.util.Log;

import netacka3d.data.Util3d;
import netacka3d.data.arena.Mesh;
import netacka3d.data.arena.MeshData;
import netacka3d.data.MatchSettings;
import netacka3d.misc.Logger;

//#replace GL GL10
//#replace glTexParameteri glTexParameterx

public class MeshRenderer {
    private MeshData meshData;    
    private boolean initialized;
    //private MatchSettings mS;
    private Part[] parts;
    
    public MeshRenderer(MeshData meshData) {
        this.meshData = meshData;
        this.initialized = false;
    }
    
    private static class Material {
        float[] amb, diff;
        Texture texture;
               
        public Material(GL gl, Mesh.Material m) {
            amb = new float[] {
                m.ambientColor.x,
                m.ambientColor.y,
                m.ambientColor.z,
                1.0f
            };
            diff = new float[] {
                m.diffuseColor.x,
                m.diffuseColor.y,
                m.diffuseColor.z,
                1.0f
            };
            if (m.diffuseTexture != null)
                texture = new Texture(gl, m.diffuseTexture);
        }
        
        public void use(GL gl) {
            gl.glMaterialfv(GL.GL_FRONT_AND_BACK, GL.GL_AMBIENT, amb, 0);
            gl.glMaterialfv(GL.GL_FRONT_AND_BACK, GL.GL_DIFFUSE, diff, 0);
            if (texture != null) {
                gl.glEnable(GL.GL_TEXTURE_2D);
                gl.glBindTexture(GL.GL_TEXTURE_2D, texture.num);                
            } else
                gl.glDisable(GL.GL_TEXTURE_2D);
        }
        
        public void destroy(GL gl) {
            if (texture != null)
                texture.destroy(gl);
        }
    }
    
    private static class Part {
        private FloatBuffer vBuf, nBuf, tcBuf;
        private Material mat;
        
        public Part(GL gl, MeshData.Buffers b) {
            vBuf = Util3d.newNativeFloatBuffer(b.vs);
            nBuf = Util3d.newNativeFloatBuffer(b.ns);
            tcBuf = Util3d.newNativeFloatBuffer(b.tcs);
            mat = new Material(gl, b.material);
        }
        
        public void display(GL gl) {
            if (vBuf.limit() == 0)
                return;
            gl.glVertexPointer(3, GL.GL_FLOAT, 0, vBuf);
            gl.glNormalPointer(GL.GL_FLOAT, 0, nBuf);
            gl.glTexCoordPointer(2, GL.GL_FLOAT, 0, tcBuf);
            mat.use(gl);
            gl.glDrawArrays(GL.GL_TRIANGLES, 0, vBuf.limit()/3);
        }
        
        public void destroy(GL gl) {
            mat.destroy(gl);
        }
    }
    
    public void init(GL gl) {
        parts = new Part[meshData.bufs.length];
        for (int i = 0; i < meshData.bufs.length; ++i)
            parts[i] = new Part(gl, meshData.bufs[i]);
        initialized = true;
    }
    
    public void destroy(GL gl) {
        for (Part p: parts)
            p.destroy(gl);
    }
    
    public void display(GL gl) {
        if (!initialized)
            init(gl);
        
        gl.glEnableClientState(GL.GL_NORMAL_ARRAY);
        gl.glEnableClientState(GL.GL_TEXTURE_COORD_ARRAY);

        gl.glMatrixMode(GL.GL_TEXTURE);
        gl.glLoadIdentity();
        gl.glMatrixMode(GL.GL_MODELVIEW);
        
        for (Part p: parts)
            p.display(gl);
        
        gl.glDisableClientState(GL.GL_NORMAL_ARRAY);
        gl.glEnableClientState(GL.GL_TEXTURE_COORD_ARRAY);
    }
}
