/*
 * This file is a part of Netacka 3D.
 *
 * Copyright 2010
 * Leszek Bartkowski, Mikołaj Dądela, Paweł Marczewski, Jan Szejko
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */


package netacka3d.misc.pc;

import java.awt.image.BufferedImage;
import java.io.InputStream;
import java.io.FileNotFoundException;
import java.io.IOException;
import java.nio.ByteBuffer;

import javax.imageio.ImageIO;

import netacka3d.data.Util3d;
import netacka3d.misc.FileIOBackend;
import netacka3d.misc.Logger;

public class PcFileIOBackend extends FileIOBackend {

    @Override
    public InputStream openFile(String filename) 
            throws FileNotFoundException {
        Logger.i("Opening " + filename);
        InputStream is = this.getClass().getResourceAsStream(
                            "/data/"+filename);
        if (is == null)
            throw new FileNotFoundException(filename);
        return is;
    }
    
    @Override
    public ByteBuffer loadImage(String filename, int[] dims) 
                throws IOException {
        Logger.i("Loading image " + filename);
        BufferedImage image = ImageIO.read(openFile(filename));
        
        if (dims != null) {
            dims[0] = image.getWidth();
            dims[1] = image.getHeight();
        }
        
        int[] data = image.getRGB(0, 0, dims[0], dims[1], null, 0, dims[0]);
        return Util3d.newPixelBuffer(data);        
    }
    
}


